@@ -336,7 +336,8 @@ char *sniffer_match(struct packet *p, struct sniff_info *si, struct sniff_log **
 	char *retval = NULL;
 	struct list_iterator li;
 	struct sniff_log *slog;
-
+	void *rret;
+	
 	list_iter_set(&li, &si->log);
 	retval = NULL;
 	while ((slog = list_iter_get(&li))) {
@@ -375,7 +376,8 @@ char *sniffer_match(struct packet *p, struct sniff_info *si, struct sniff_log **
 		if (p->p_hdr.p_tcph->rst || p->p_hdr.p_tcph->fin) {
 			/* ok, wee don't handle half open connection */
 			sniffer_log_print(si, slog);
-			assert(list_remove(&si->log, slog));
+			rret = list_remove(&si->log, slog);
+			assert(rret);
 			free_sniff_log(slog);
 			retval = NULL;
 		}	
@@ -634,7 +636,7 @@ static void sniff_add_item(void)
 			&dst_mask, dst_ports, 0, 0, NULL) < 0)
 		return;
 	buf_p = NULL;
-	srch_mode = MODE_BOTH;
+	srch_mode = 'b';
 	switch (menu_choose_char("want to search for y/n", "yn", 'y')) {
 	    case 'y':
 		if ((srch_mode = menu_choose_sdb("srch_mode", 'b')) == -1)
@@ -677,7 +679,8 @@ static void sniff_add_item(void)
 	
 	if (buf_p) {
 		len = strlen(buf_p) + 1;
-		assert(si->search = malloc(len));
+		si->search = malloc(len);
+		assert(si->search);
 		memcpy(si->search, buf_p, len);
 	}
 	si->log_mode = sdb_to_int(log_mode);
@@ -715,11 +718,12 @@ static void sniff_mod_item(void)
 			    &dst_ip, &dst_mask, dst_ports,
 			    si->dst_addr, si->dst_mask, si->dst_ports) < 0)
 		return;
-	if ((srch_mode = menu_choose_sdb("srch_mode", int_to_sdb(si->srch_mode))) < 0)
-		return;
 	buf_p = NULL;
+	srch_mode = 'b';
 	switch (menu_choose_char("want to search for y/n", "yn", 'y')) {
 	    case 'y':
+		if ((srch_mode = menu_choose_sdb("srch_mode", int_to_sdb(si->srch_mode))) < 0)
+			return;
 		if (menu_choose_string("search for", buf, sizeof(buf), si->search) < 0)
 			return;
 		buf_p = buf;
@@ -747,7 +751,8 @@ static void sniff_mod_item(void)
 	if (buf_p) {
 		free(si->search);
 		len = strlen(buf_p) + 1;
-		assert(si->search = malloc(len));
+		si->search = malloc(len);
+		assert(si->search);
 		memcpy(si->search, buf_p, len);
 	}
 	si->log_mode = sdb_to_int(log_mode);
